package org.gfxtest.testsuites;

import java.awt.*;
import java.awt.geom.AffineTransform;
import java.io.IOException;

import org.gfxtest.framework.*;

public class DashedRectangles extends GfxTest
{
    private static final float DEFAULT_SCALE = 20.0f;
    private static final int OFFSET = 80;

    private void drawRectangle(TestImage image, Graphics2D graphics, float scale, int cap, int join, float[] dash)
    {
        graphics.setColor(Color.BLACK);
        graphics.setStroke(new BasicStroke(1,                  // width
                                     cap,                      // cap
                                     join,                     // join
                                     1.0f,
                                     dash,                     // dash
                                     0.0f));                   // dash phase
        graphics.scale(scale, scale);
        int x1 = (int) (OFFSET / scale);
        int y1 = (int) (OFFSET / scale);
        int x2 = (int) ((image.getWidth() - OFFSET) / scale);
        int y2 = (int) ((image.getHeight() - OFFSET) / scale);
        graphics.drawRect(x1, y1, x2 - x1, y2 - y1);

        graphics.setTransform(new AffineTransform());
        drawCross(graphics, OFFSET, OFFSET, CROSS_SIZE);
        drawCross(graphics, image.getWidth() - OFFSET, image.getHeight() - OFFSET, CROSS_SIZE);
    }

    protected void runOtherTests(Configuration configuration)
    {
        int[] caps = { BasicStroke.CAP_SQUARE, BasicStroke.CAP_BUTT, BasicStroke.CAP_ROUND };
        int[] joins = { BasicStroke.JOIN_BEVEL, BasicStroke.JOIN_MITER, BasicStroke.CAP_ROUND };
        int testNumber = 0;
        for (int join : joins)
        {
            for (int cap : caps)
            {
                for (float dash1 = 0.25f; dash1 <= 4.0; dash1 *= 2.0)
                {
                    for (float dash2 = 0.25f; dash2 <= 4.0; dash2 *= 2.0)
                    {
                        String testName = "test" + testNumber;
                        log.logBegin(testName);
                        TestImage image = new TestImage(configuration);
                        Graphics2D graphics = (Graphics2D) image.getGraphics();
                        drawRectangle(image, graphics, DEFAULT_SCALE, cap, join, new float[]
                        { dash1, dash2 });
                        graphics.dispose();
                        try
                        {
                            image.writeImage(configuration, suiteName, testName);
                        }
                        catch (IOException e)
                        {
                            e.printStackTrace();
                        }
                        log.logEnd(testName);
                        testNumber++;
                    }
                }
            }
        }
    }

    public static void main(String[] args)
    {
        new DashedRectangles().runTestSuite(args);
    }
}
