package org.gfxtest.testsuites;

import java.awt.*;
import java.awt.geom.AffineTransform;
import java.io.IOException;

import org.gfxtest.framework.*;

public class ScaledLines extends GfxTest
{
    private static final int OFFSET = 80;

    private void drawScaledLine(TestImage image, Graphics2D graphics, float scale, int cap)
    {
        graphics.setColor(Color.BLACK);
        graphics.setStroke(new BasicStroke(1,                  // width
                                     cap,                      // cap
                                     BasicStroke.JOIN_ROUND)); // join
        graphics.scale(scale, scale);
        int x1 = (int) (OFFSET / scale);
        int y1 = (int) (OFFSET / scale);
        int x2 = (int) ((image.getWidth() - OFFSET) / scale);
        int y2 = (int) ((image.getHeight() - OFFSET) / scale);
        graphics.drawLine(x1, y1, x2, y2);

        graphics.setTransform(new AffineTransform());
        drawCross(graphics, OFFSET, OFFSET, CROSS_SIZE);
        drawCross(graphics, image.getWidth() - OFFSET, image.getHeight() - OFFSET, CROSS_SIZE);
    }

    protected void runOtherTests(Configuration configuration)
    {
        float[] scales = { 1.0f, 10.0f, 20.0f, 40.0f, 80.0f };
        int[] caps =     { BasicStroke.CAP_SQUARE, BasicStroke.CAP_BUTT, BasicStroke.CAP_ROUND };
        int testNumber = 0;
        for (int cap : caps)
        {
            for (float scale : scales)
            {
                String testName = "test" + testNumber;
                log.logBegin(testName);
                TestImage image = new TestImage(configuration);
                Graphics2D graphics = (Graphics2D) image.getGraphics();
                drawScaledLine(image, graphics, scale, cap);
                graphics.dispose();
                try
                {
                    image.writeImage(configuration, suiteName, testName);
                }
                catch (IOException e)
                {
                    e.printStackTrace();
                }
                log.logEnd(testName);
                testNumber++;
            }
        }
    }

    public static void main(String[] args)
    {
        new ScaledLines().runTestSuite(args);
    }
}
