package org.gfxtest.testsuites;

import java.awt.*;
import java.awt.geom.*;
import java.io.IOException;

import org.gfxtest.framework.*;

public class ScaledRectangles extends GfxTest
{
    private static final int OFFSET = 80;

    private void drawScaledRectangle(TestImage image, Graphics2D graphics, float scale, int cap, int join)
    {
        graphics.setColor(Color.BLACK);
        graphics.setStroke(new BasicStroke(1,                  // width
                                     cap,                      // cap
                                     join));                   // join
        graphics.scale(scale, scale);
        int x1 = (int) (OFFSET / scale);
        int y1 = (int) (OFFSET / scale);
        int x2 = (int) ((image.getWidth() - OFFSET) / scale);
        int y2 = (int) ((image.getHeight() - OFFSET) / scale);

        graphics.drawRect(x1, y1, x2 - x1, y2 - y1);

        graphics.setTransform(new AffineTransform());
        drawCross(graphics, OFFSET, image.getHeight() - OFFSET, CROSS_SIZE);
        drawCross(graphics, image.getWidth() / 2, OFFSET, CROSS_SIZE);
        drawCross(graphics, image.getWidth() - OFFSET, image.getHeight() - OFFSET, CROSS_SIZE);
    }

    protected void runOtherTests(Configuration configuration)
    {
        float[] scales = { 1.0f, 10.0f, 20.0f, 40.0f, 80.0f };
        int[] joins =    { BasicStroke.JOIN_BEVEL, BasicStroke.JOIN_MITER, BasicStroke.CAP_ROUND };
        int testNumber = 0;
        for (int join : joins)
        {
            for (float scale : scales)
            {
                String testName = "test" + testNumber;
                log.logBegin(testName);
                TestImage image = new TestImage(configuration);
                Graphics2D graphics = (Graphics2D) image.getGraphics();
                drawScaledRectangle(image, graphics, scale, BasicStroke.CAP_BUTT, join);
                graphics.dispose();
                try
                {
                    image.writeImage(configuration, suiteName, testName);
                }
                catch (IOException e)
                {
                    e.printStackTrace();
                }
                log.logEnd(testName);
                testNumber++;
            }
        }
    }

    public static void main(String[] args)
    {
        new ScaledRectangles().runTestSuite(args);
    }
}
